# adirondax
A differentiable astrophysics simulator in JAX

Author: [Philip Mocz (@pmocz)](https://github.com/pmocz/)

Adirondax is a scientific research software for carrying out astrophysical and cosmological simulations and solving inverse-problems. It is written in JAX and GPU-ready.

## Getting started

Install with 

```console
pip install adirondax
```

Check out the `examples` directory for demonstrations of using Adirondax.

## Links


## Cite this repository

